==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_cs.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("To je snad vikingská loď!")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Jistě, je to drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Musela se potopit hrozně rychle. Veslaři ještě sedí na svých místech.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Možná, že ji potopili schválně. Bojovníci doprovázejí svého velitele do Valhaly...")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Hrůza... sedí tu jako živí...")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Hudba je v tahu!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Přestali hrát!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Zase vypadla hudba!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("To snad ne!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Už zase?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Už se to stalo zase?")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Co se děje?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Už zase?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("To snad ne!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("To snad není možný!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Co tam nahoře dělají?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Jak je tohle možný?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Nevadí, chapci. Olaf sólo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Nevadí, chapci. Zazpíváme si sami!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("To nevadí. Zazpíváme si sami, jako za mlada!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_cs.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("To je snad vikingská loď!")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Jistě, je to drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Musela se potopit hrozně rychle. Veslaři ještě sedí na svých místech.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Možná, že ji potopili schválně. Bojovníci doprovázejí svého velitele do Valhaly...")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Hrůza... sedí tu jako živí...")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Hudba je v tahu!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Přestali hrát!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Zase vypadla hudba!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("To snad ne!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Už zase?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Už se to stalo zase?")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Co se děje?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Už zase?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("To snad ne!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("To snad není možný!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Co tam nahoře dělají?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Jak je tohle možný?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Nevadí, chapci. Olaf sólo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Nevadí, chapci. Zazpíváme si sami!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("To nevadí. Zazpíváme si sami, jako za mlada!")
